@@ -7,6 +7,7 @@ creating callback data strings and parsing it from call's data.
 EXTERNAL_MARK_SEPARATOR = "&"
 INTERNAL_MARK_SEPARATOR = "="
 DEFAULT_MARK_VALUE = "*"
+
 EMS = EXTERNAL_MARK_SEPARATOR
 IMS = INTERNAL_MARK_SEPARATOR
 DMV = DEFAULT_MARK_VALUE
@@ -20,6 +21,13 @@ def info_from_callback(call_data: str, separators: tuple = (EMS, IMS, DMV)) -> d
     :return:
     """
 
+    if not isinstance(call_data, str):
+        raise TypeError(f"call_data should be a str type. You input {type(call_data)}.")
+
+    for sep in separators:
+        if not isinstance(sep, str):
+            raise TypeError(f"Separator should be a str type. You input {type(sep)}.")
+
     _ems, _ims, _ = separators
     separated_items = call_data.split(_ems)
     parsed_items = [element.split(_ims)
@@ -40,9 +48,18 @@ def callback_from_info(info: dict, separators: tuple = (EMS, IMS, DMV)) -> str:
     :param separators:
     :return:
     """
+    if not isinstance(info, dict):
+        raise TypeError(f"info should be a dict type. You input {type(info)}.")
+
+    for sep in separators:
+        if not isinstance(sep, str):
+            raise TypeError(f"Separator should be a str type. You input {type(sep)}.")
+
     _ems, _ims, _ = separators
-    return "".join(["%s%s%s%s" % (_ems, mark, _ims, value) for mark, value in info.items()])
 
+    callback = "".join(["%s%s%s%s" % (_ems, mark, _ims, value) for mark, value in info.items()])
 
-if __name__ == "__main__":
-    pass
+    if len(callback) > 64:
+        raise ValueError("The length of callback_data should not be more that 64 symbols."
+                         f"Your callback's length is {len(callback)} symbols.")
+    return callback
